from .diskInfo import diskInfo
from .installPythonModule import installPythonModule
from .internetInfo import internetInfo
from .killChrome import killChrome
from .listDrives import listDrives
from .listUsers import listUsers
from .netSupport import killNetSupport
from .performanceMonitor import performanceMonitor
from .systemInfo import systemInfo
from .taskManager import taskManager
from .treeDrives import treeDrives
